#
# Copyright (c) 2019, Hewlett Packard Enterprise Development LP
#

from __future__ import print_function
from .. import SubCommand
from ..constants import DEFAULT_CONFIG_API_VER
from .appconfig_autogen import copyAppconfigStarter

import os


class AppconfigInitcode(SubCommand):
    """

    """

    def __init__(self, config, inmemStore, cmdObj):
        SubCommand.__init__(self, config, inmemStore, cmdObj, 'init')

    def getSubcmdDescripton(self):
        return 'When manually developing appconfig script, this copies a few ' +\
               'useful scripts that you can use as starter code.'

    def populateParserArgs(self, subparser):
        subparser.add_argument('-d', '--dir', metavar='DESTINATION_DIR', type=str,
                               dest='destdir', required=True,
                               help='A directory where the starter code is to '
                                    'be copied. This directory and all its parents '
                                    'will be created if they do not already exist.')
        subparser.add_argument('--configapi', action='store', dest='configapi',
                               type=int, default=DEFAULT_CONFIG_API_VER,
                               help='The config api version used by the scripts '
                               'in the appconfig package.')

    def run(self, pArgs):
        absDir = os.path.abspath(pArgs.destdir)

        if not os.path.exists(absDir):
            os.makedirs(absDir)

        if os.path.isdir(absDir):
            copyAppconfigStarter(self.config, pArgs.configapi, absDir)
            return True
        else:
            print("ERROR: '%s' is not a directory" % (absDir))
            return False

    def complete(self, text, argsList):
        return []
