#!/bin/env python
#
# Copyright (c) 2019, Hewlett Packard Enterprise Development LP

from __future__ import print_function
from .. import Command

from .attach_distro import AttachDistro
from .attach_service import AttachService
from .attach_category import AttachCategory

from ..inmem_store import ENTRY_DICT
from ..constants import ATTACHABLES_SUPPORT


class Attach(Command):
    """

    """

    def __init__(self, wb, config, inmemStore):
        Command.__init__(self, wb, config, inmemStore, 'attach',
                         'Defines what other application can be attached.')

        # Initialize the subcommands.
        AttachDistro(config, inmemStore, self)
        AttachService(config, inmemStore, self)
        AttachCategory(config, inmemStore, self)

    def getAttachableDict(self):
        """
        Returns the existing attachables list from the catalog entry or
        an empty list.
        """
        entryDict = self.inmemStore.getDict(ENTRY_DICT)

        return entryDict['attachable_to'] if entryDict.has_key(
            'attachable_to') else[]

    def setAttachableDict(self, value):
        """
        Replace any previous
        """
        self.inmemStore.mergeDict(ENTRY_DICT, {'attachable_to': value})

    def updateAttachables(self, subcmd, key, inputList):
        """
        Adds {key: value} for each value in the inputList to the 'attachable_to'
        list in the catalog entry json.
        """
        if not self.isSupported(subcmd):
            return False

        attachableDictList = self.getAttachableDict()

        for inputElement in inputList:
            for definedDict in attachableDictList:
                if definedDict.has_key(key) and (str(definedDict[key]) == str(inputElement)):
                    break
            else:
                # {key:inputElement} not already in the attachable dictionary list.
                attachableDictList.append({key: inputElement})

        self.setAttachableDict(attachableDictList)

    def isSupported(self, cmd):
        """
        Check if the catalog api version supports using attachments.
        """
        entryDict = self.inmemStore.getDict(ENTRY_DICT)

        isSupported = False
        if entryDict.has_key('catalog_api_version'):
            catalogApi = int(entryDict['catalog_api_version'])
            isSupported = (catalogApi >= int(ATTACHABLES_SUPPORT))

            if not isSupported:
                print("ERROR: Application attachments not supported for "
                      "catalog api version", catalogApi)
        else:
            print("ERROR: Unknown catalog API vesion to determine "
                  "attachments' support. Please use 'catalog new' or "
                  "'catalog load' to specify.")

        return isSupported


__all__ = ['Attach']
Command.register(Attach)
