# Copyright (c) 2019, Hewlett Packard Enterprise Development LP
#

from __future__ import print_function
from .. import SubCommand
from ..inmem_store import ENTRY_DICT


class AttachService(SubCommand):
    """

    """

    def __init__(self, config, inmemStore, cmdObj):
        self.name = 'service'
        SubCommand.__init__(self, config, inmemStore, cmdObj, self.name)

    def getSubcmdDescripton(self):
        return 'Attach applications based on exported services and qualifiers.'

    def populateParserArgs(self, subparser):
        subparser.add_argument('-s', '--service', metavar='SERVICE', type=str,
                               dest='services', required=True, action='append',
                               help='An application with the given service name '
                               'is atttachable to this cluster.')
        subparser.add_argument('-q', '--qualifier', metavar='QUALIFIER', type=str,
                               dest='qualifiers', action='append',
                               help='An optional service qualifier that futher '
                               'narrows down the attachable applications.')

    def run(self, pargs):
        if not self.command.isSupported(self.name):
            return False

        qualifiers = pargs.qualifiers
        if not qualifiers:
            qualifiers = [None for i in range(len(pargs.services))]
        elif len(qualifiers) < len(pargs.services):
            # extend qualifiers list to the same length as service.
            diffLen = len(pargs.services) - len(qualifiers)
            qualifiers.extend([None for i in range(diffLen)])
        elif len(qualifiers) > len(pargs.services):
            print("ERROR: Each service may only have one qualifier specified.")
            return False

        attachableDictList = self.command.getAttachableDict()

        for srvc, qualifier in zip(pargs.services, qualifiers):
            for definedDict in attachableDictList:
                if definedDict.has_key('service') and (str(definedDict['service']) == str(srvc)):
                    if qualifier:
                        definedDict['qualifier'] = qualifier
                    elif definedDict.has_key('qualifier'):
                        # service attachment was redefined but no qualifier specified.
                        # Assume user wants to remove the qualifier. This is useful when
                        # modifying contents of an existing entry json.
                        definedDict.pop('qualifier')

                    break
            else:
                # service not already in the attachable dictionary list.
                newSrvcDep = {'service': srvc}
                if qualifier:
                    newSrvcDep['qualifier'] = qualifier

                attachableDictList.append(newSrvcDep)

        self.command.setAttachableDict(attachableDictList)
        return True

    def complete(self, text, argsList):
        return []


__all__ = ['AttachService']
