#!/bin/bash
#
# Builds CentOS/RHEL 6.x images.
#set -x

UPSTREAM=''
IMGVERSION=''
TEMPLATE_BASE=''

print_help() {
    echo
    echo "USAGE: $0 [ -h ]"
    echo
    echo "                  -h    : Prints usage details and exits."
    echo ""
    echo "             --upstream : What upstream docker image to use."
    echo
    echo "              --imgname : Base image name."
    echo "           --imgversion : Base image version of MAJOR.MINOR format."
    echo "           --imgorgname : Organization name of the base image builder."
    echo "      --baseimg-version : Version indicating which EPIC features are supported."
    echo ""
    echo "         --template_dir : Template base directory."
    echo
}

parse_options() {
    while [ $# -gt 0 ]; do
        case $1 in
            -h|--help)
                print_help
                exit 0
                ;;
            --baseimg-version)
                EPIC_BASE_IMG_VERSION=$2;
                shift 2
                ;;
            --imgname)
                IMGNAME=$2
                shift 2
                ;;
            --imgorgname)
                ORGNAME=$2
                shift 2
                ;;
            --template_dir)
                TEMPLATE_BASE=$2
                shift 2
                ;;
            --imgversion)
                IMGVERSION=$2
                shift 2
                ;;
            --upstream)
                UPSTREAM=$2
                shift 2
                ;;
            --)
                shift
                ;;
            *)
                echo "Unknown option $1."
                print_help
                exit 1
                ;;
        esac
    done

    if [[ -z "${IMGVERSION}" ]] || [[ -z "${TEMPLATE_BASE}" ]] ||\
        [[ -z "${UPSTREAM}" ]]; then
        echo "ERROR: --imgversion, --upstream and --template_dir must be specified."
        exit 1
    fi

    [[ -z ${EPIC_BASE_IMG_VERSION} ]] && EPIC_BASE_IMG_VERSION=${IMGVERSION}
}

SHORTOPTS="h"
LONGOPTS="imgname:,imgorgname:,imgversion:,baseimg-version:,template_dir:,upstream:,help"
OPTS=$(getopt -u --options=$SHORTOPTS --longoptions=$LONGOPTS -- "$@")
if [ $? -ne 0 ]; then
    echo "ERROR: Unable to parse the option(s) provided."
    print_help
    exit 1
fi

parse_options $OPTS

build_docker_image() {
    docker build -t $1 $2
    if [[ $? -ne 0 ]]; then
        echo "ERROR: Failed to build docker image: $1"
        exit 1
    fi
}

create_docker_tag() {
    docker tag $1 $2
    if [[ $? -ne 0 ]]; then
        echo "ERROR: Failed to tag docker image: $1"
        exit 1
    fi
}

echo "${EPIC_BASE_IMG_VERSION}" > ${TEMPLATE_BASE}/base_img_version

echo "Build Container base image"
cp ${TEMPLATE_BASE}/Dockerfile.template  ${TEMPLATE_BASE}/Dockerfile
sed -i "s~@@@@UPSTREAM@@@@~${UPSTREAM}~g" ${TEMPLATE_BASE}/Dockerfile

build_docker_image "${ORGNAME}/${IMGNAME}:${IMGVERSION}" ${TEMPLATE_BASE}
create_docker_tag "${ORGNAME}/${IMGNAME}:${IMGVERSION}" "${ORGNAME}/${IMGNAME}:latest"
