#!/bin/env python
#
# Copyright (c) 2019, Hewlett Packard Enterprise Development LP

from __future__ import print_function
from .. import Command

from .catalog_new import CatalogNew
from .catalog_save import CatalogSave
from .catalog_load import CatalogLoad
from .catalog_modify import CatalogModify
from .catalog_package import CatalogPackage

from ..constants import AIML_CATEGORIES, DEFAULT_EPIC_API_DICT


class Catalog(Command):
    """

    """

    def __init__(self, wb, config, inmemStore):
        Command.__init__(self, wb, config, inmemStore, 'catalog',
                         'Catalog entry management.')

        # Initialize the subcommands.
        CatalogNew(config, inmemStore, self)
        CatalogSave(config, inmemStore, self)
        CatalogLoad(config, inmemStore, self)
        CatalogModify(config, inmemStore, self)
        CatalogPackage(config, inmemStore, self)

    def catalogCommonArgs(self, subparser):
        subparser.add_argument('--distroid', metavar='DISTRO_ID', type=str,
                               required=True, action='store',
                               help='A unique distro id.')
        subparser.add_argument('--name', dest='name', metavar="NAME",
                               type=str, action='store', required=True,
                               help='Catalog name for the end user. Enclose in '
                                    'double quotes for names with spaces.')
        subparser.add_argument('--depends_on', metavar='DISTRO_ID',
                               dest='dependsOn', type=str, default=None,
                               help='Distro id of another catalog this entry '
                               'depends on. This option is used to indicate '
                               'that this is an add-on catalog entry.')
        subparser.add_argument('--desc', metavar="DESCRIPTIOIN", dest='desc',
                               type=str, action='store', required=True,
                               help='Catalog description for the end user. Use '
                                    'double quotes to enclose the description.')
        subparser.add_argument('-v', '--version', metavar='VERSION', dest='version',
                               type=str, action='store', default=None,
                               help='Catalog entry version of the form: MAJOR.MINOR '
                                    'or MAJOR.MINOR.BUILD. Version of the form '
                                    'MAJOR.MINOR.BUILD is assumed to be a debug '
                                    'mode version, and its BUILD will be auto-incremented '
                                    'on every subsequent CATALOG SAVE command.')
        subparser.add_argument('-r', '--recommend_distro', metavar='RECOMMEND_DISTRO',
                               type=str, dest='recdistro', default=None,
                               help='A distro ID EPIC may recommend when creating a cluster.'),

        categoryparser = subparser.add_mutually_exclusive_group()
        categoryparser.add_argument('-c', '--categories', metavar='CATEGORIES',
                                    type=str, dest='categories', action='store',
                                    nargs='+', default=None,
                                    help='A space separated list of categories this '
                                    'entry will be available under during cluster '
                                    'creation.')
        categoryparser.add_argument('-a', '--aiml-categories', metavar='AIML_CATEGORIES',
                                    type=str, dest='categories', action='store',
                                    nargs='+', default=None, choices=AIML_CATEGORIES,
                                    help='A space separated list of AIML categories. '
                                    'Choices: ' + str(AIML_CATEGORIES))

        apiparser = subparser.add_mutually_exclusive_group()
        apiparser.add_argument('--catalogapi', metavar='CATALOG_API_VERSION',
                               dest='catalogapi', type=str, default=None,
                               help='Catalog api version used by this entry.')
        apiparser.add_argument('--epic', metavar='EPIC_VERSION',
                               dest='targetepic', type=str, default=None,
                               choices=DEFAULT_EPIC_API_DICT.keys(),
                               help='EPIC platform version where the catalog '
                               'entry will be installed. Choices: ' +
                               str(sorted(DEFAULT_EPIC_API_DICT.keys())))


__all__ = ['Catalog']
Command.register(Catalog)
