# Copyright (c) 2019, Hewlett Packard Enterprise Development LP
#

from __future__ import print_function
from .. import SubCommand
from ..constants import DEFAULT_CATEGORY_HADOOP
from ..inmem_store import ENTRY_DICT
from ..utils.misc import constructDistroId as constructDistroId


class CatalogModify(SubCommand):
    """

    """

    def __init__(self, config, inmemStore, cmdObj):
        SubCommand.__init__(self, config, inmemStore, cmdObj, 'modify')

    def getSubcmdDescripton(self):
        return 'Allows slected fields in the catalog entry to be updated.'

    def populateParserArgs(self, subparser):
        self.command.catalogCommonArgs(subparser)

    def run(self, pargs):
        if pargs.distroid != None:
            newDistroId = constructDistroId(self.inmemStore, self.config,
                                            pargs.distroid)
            if newDistroId != None:
                self.inmemStore.addField(
                    ENTRY_DICT, "distro_id", newDistroId.lower())
            else:
                # constructDistroID would have logged the error.
                return False

        if pargs.name != None or pargs.desc != None:
            entryDict = self.inmemStore.getDict(ENTRY_DICT)

            if not entryDict.has_key('label'):
                entryDict['label'] = {}

            labelDict = entryDict['label']

            if pargs.name != None:
                labelDict['name'] = pargs.name

            if pargs.desc != None:
                labelDict['description'] = pargs.desc

        if pargs.dependsOn != None:
            self.inmemStore.addField(
                ENTRY_DICT, "distro_dependency", pargs.dependsOn)

        if pargs.version != None:
            self.inmemStore.addField(ENTRY_DICT, "version", pargs.version)

        if pargs.catalogapi != None:
            self.inmemStore.addField(
                ENTRY_DICT, "catalog_api_version", pargs.catalogapi)

        if pargs.categories != None:
            self.inmemStore.addField(
                ENTRY_DICT, "categories", pargs.categories)

        if pargs.recdistro != None:
            self.inmemStore.addField(
                ENTRY_DICT, "recommended_dep_distro_id", pargs.recdistro)

        # Verify that the requires parameters are set.
        entryDict = self.inmemStore.getDict(ENTRY_DICT)

        errkeylist = []
        for key in ['version', 'distro_id', 'catalog_api_version', 'categories']:
            if not entryDict.has_key(key):
                errkeylist.append(key)

        if not entryDict.has_key('label'):
            errkeylist.extend(['name', 'description'])
        else:
            labelDict = entryDict['label']
            if not labelDict.has_key('name'):
                errkeylist.append('name')

            if not labelDict.has_key('description'):
                errkeylist.append('description')

        if len(errkeylist) > 0:
            print("ERROR: Following app properties are mandatory: ",
                  ','.join(errkeylist))
            return False

        return True

    def complete(self, text, argsList):
        return []
