# Copyright (c) 2019, Hewlett Packard Enterprise Development LP
#

from __future__ import print_function
from .. import SubCommand

from ..inmem_store import ENTRY_DICT
from ..constants import DEFAULT_CONFIG_API_VER
from ..constants import DEFAULT_STR_VERSION, DEFAULT_CATEGORY_HADOOP, DEFAULT_EPIC_API_DICT

from ..utils.misc import constructDistroId as constructDistroId


class CatalogNew(SubCommand):
    """

    """

    def __init__(self, config, inmemStore, cmdObj):
        SubCommand.__init__(self, config, inmemStore, cmdObj, 'new')

    def getSubcmdDescripton(self):
        return 'Starts a session for creating a new catalog entry. ' +\
               'Any previouly started sessions will be lost unless they ' +\
               'were saved.'

    def populateParserArgs(self, subparser):
        self.command.catalogCommonArgs(subparser)

    def run(self, pargs):
        use_distroId = constructDistroId(self.inmemStore, self.config,
                                         pargs.distroid)
        if use_distroId == None:
            return False

        distroId = use_distroId.lower()

        if pargs.targetepic != None:
            catalogapi, configapi = DEFAULT_EPIC_API_DICT[pargs.targetepic]
        else:
            if not pargs.catalogapi:
                print(
                    "ERROR: --catalogapi or --epic must be specified for 'catalog new' command")
                return False

            catalogapi = pargs.catalogapi
            configapi = DEFAULT_CONFIG_API_VER

        version = DEFAULT_STR_VERSION if not pargs.version else pargs.version
        categories = [DEFAULT_CATEGORY_HADOOP] if not pargs.categories else \
            pargs.categories

        self.inmemStore.clear(ENTRY_DICT)
        self.inmemStore.addField(ENTRY_DICT, "distro_id", "%s" % (distroId))
        self.inmemStore.addField(ENTRY_DICT, "label", {"name": pargs.name,
                                                       "description": pargs.desc})
        self.inmemStore.addField(ENTRY_DICT, "version", version)
        self.inmemStore.addField(ENTRY_DICT, "catalog_api_version", catalogapi)
        self.inmemStore.addField(ENTRY_DICT, "categories", categories)
        self.inmemStore.addField(ENTRY_DICT, "setup_package",
                                 {"config_api_version": configapi})
        if pargs.dependsOn != None:
            self.inmemStore.addField(ENTRY_DICT, "distro_dependency",
                                     pargs.dependsOn)
        if pargs.recdistro != None:
            self.inmemStore.addField(
                ENTRY_DICT, "recommended_dep_distro_id", pargs.recdistro)

        return True

    def complete(self, text, argsList):
        return []
