#
# Copyright (c) 2019 BlueData Software, Inc.
#

from __future__ import print_function
from .. import SubCommand
from ..constants import *
from ..inmem_store import ENTRY_DICT
from ..utils.misc import downloadFile, calculateMD5SUM

class DocumentDownload(SubCommand):
    """

    """
    def __init__(self, config, inmemStore, cmdObj):
        SubCommand.__init__(self, config, inmemStore, cmdObj, 'download')

    def getSubcmdDescripton(self):
        return 'Download the document file from a HTTP url and add it to the '    \
               'catalog feed entry.'

    def populateParserArgs(self, subparser):
        subparser.add_argument('-l', '--url', metavar='DOCUMENT_URL', type=str,
                               dest='documenturl', action='store', required=True,
                               help='HTTP URL for downloading the document file. '
                               'The file is downloaded to the staging directory.')
        subparser.add_argument('--md5sum', metavar='MD5SUM', type=str,
                               dest='md5sum', action='store', required=False,
                               help='MD5 checksum of the document file: used to verify '
                               'the checksum immediatly after downloading.')

    def run(self, pargs):
        localfile = downloadFile(pargs.documenturl, pargs.md5sum, self.config)
        if localfile == None:
            return False

        # md5sum is optional
        md5 = calculateMD5SUM(localfile) if pargs.md5sum is None else pargs.md5sum

        return self.workbench.onecmd("document file --filepath %s --md5sum %s" %
                                                    (localfile, md5))

    def complete(self, text, argsList):
        return []
